<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../aboutdialog.cpp" line="29"/>
        <source>About</source>
        <translation>情報</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="32"/>
        <source>Launch application with image file path as argument to load the file.</source>
        <translation>画像ファイルのパスをパラメータとしてアプリケーションを起動すると、ファイルを読み込みます。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="33"/>
        <source>Drag and drop image file onto the window is also supported.</source>
        <translation>画像ファイルをウィンドウにドラッグ＆ドロップすることもできます。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="34"/>
        <source>None of the operations in this application will alter the pictures on disk.</source>
        <translation>このアプリのどの操作も、ディスク上の写真に変更を加えることはありません。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="35"/>
        <source>Context menu option explanation:</source>
        <translation>コンテキストメニューのオプションの説明:</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="42"/>
        <source>Make window stay on top of all other windows.</source>
        <translation>ウィンドウを最前面に表示します。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="45"/>
        <source>Avoid close window accidentally. (eg. by double clicking the window)</source>
        <translation>誤ってウィンドウを閉じないようにします。(例：ウィンドウをダブルクリックする)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="48"/>
        <source>Avoid resetting the zoom/rotation/flip state that was applied to the image view when switching between images.</source>
        <translation>画像を切り替える時に、画像表示に適用されているズーム、回転、反転の状態を維持します。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="55"/>
        <source>Version: %1</source>
        <translation>バージョン: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="66"/>
        <source>Logo designed by %1</source>
        <translation>ロゴデザイン: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="68"/>
        <source>Built with Qt %1 (%2)</source>
        <translation>Qt %1 (%2) でビルドされました</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="69"/>
        <source>Source code</source>
        <translation>ソースコード</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="79"/>
        <source>Contributors</source>
        <translation>貢献者</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="81"/>
        <source>List of contributors on GitHub</source>
        <translation>GitHubでの貢献者リスト</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="82"/>
        <source>Thanks to all people who contributed to this project.</source>
        <translation>このプロジェクトに貢献したすべての人に感謝します。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="86"/>
        <source>Translators</source>
        <translation>翻訳者</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="87"/>
        <source>I would like to thank the following people who volunteered to translate this application.</source>
        <translation>このアプリケーションの翻訳にボランティアで参加してくださった以下の方々に感謝します。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="131"/>
        <source>%1 is built on the following free software libraries:</source>
        <comment>Free as in freedom</comment>
        <translation>%1は以下のフリーソフトウェア・ライブラリで構築されています。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="155"/>
        <source>&amp;Special Thanks</source>
        <translation>スペシャルサンクス(&amp;S)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="157"/>
        <source>&amp;Third-party Libraries</source>
        <translation>サードパーティライブラリ(&amp;T)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="93"/>
        <source>Your Rights</source>
        <translation>利用者の権利</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="63"/>
        <source>Copyright (c) %1 %2</source>
        <comment>%1 is year, %2 is the name of copyright holder(s)</comment>
        <translation>Copyright (c) %1 %2</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="95"/>
        <source>%1 is released under the MIT License.</source>
        <translation>%1は、MITライセンスのもとで公開されています。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="96"/>
        <source>This license grants people a number of freedoms:</source>
        <translation>このライセンスは人々に多くの自由を与えます。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="97"/>
        <source>You are free to use %1, for any purpose</source>
        <translation>%1は、どのような目的にも自由に使用するできます</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="98"/>
        <source>You are free to distribute %1</source>
        <translation>%1を自由に配布することができます</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="99"/>
        <source>You can study how %1 works and change it</source>
        <translation>%1がどのように作動するかを研究し、それを変更することができます</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="100"/>
        <source>You can distribute changed versions of %1</source>
        <translation>変更されたバージョンの %1を配布することができます</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="102"/>
        <source>The MIT license guarantees you this freedom. Nobody is ever permitted to take it away.</source>
        <translation>MITライセンスは、この自由を保証しています。誰もそれを奪うことは許されていません。</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="130"/>
        <source>Third-party Libraries used by %1</source>
        <translation>%1が使用するサードパーティライブラリ</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="153"/>
        <source>&amp;Help</source>
        <translation>へルプ(&amp;H)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="154"/>
        <source>&amp;About</source>
        <translation>情報(&amp;A)</translation>
    </message>
    <message>
        <location filename="../aboutdialog.cpp" line="156"/>
        <source>&amp;License</source>
        <translation>ライセンス(&amp;L)</translation>
    </message>
</context>
<context>
    <name>GraphicsScene</name>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <location filename="../graphicsscene.cpp" line="100"/>
        <source>Drag image here</source>
        <translation>ここに画像をドラッグしてください</translation>
    </message>
</context>
<context>
    <name>GraphicsView</name>
    <message>
        <source>File url list is empty</source>
        <translation type="vanished">ファイルURLリストがエンプティーです</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="50"/>
        <source>File is not a valid image</source>
        <translation>ファイルが有効な画像ではありません</translation>
    </message>
    <message>
        <location filename="../graphicsview.cpp" line="54"/>
        <location filename="../graphicsview.cpp" line="58"/>
        <source>Image data is invalid or currently unsupported</source>
        <translation>無効またはサポートされていない画像データ</translation>
    </message>
    <message>
        <source>Image data is invalid</source>
        <translation type="vanished">画像のデータが無効です</translation>
    </message>
    <message>
        <source>Not supported mimedata: %1</source>
        <translation type="vanished">無効なmimedata: %1</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="181"/>
        <location filename="../mainwindow.cpp" line="545"/>
        <source>File url list is empty</source>
        <translation>ファイルurlリストがエンプティーです</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="445"/>
        <source>&amp;Copy</source>
        <translation>コピー(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Image data is invalid</source>
        <translation>画像のデータが無効です</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Not supported mimedata: %1</source>
        <translation>無効なmimedata: %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="759"/>
        <source>Image From Clipboard</source>
        <translation>クリップボードからの画像</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="777"/>
        <source>Are you sure you want to move &quot;%1&quot; to recycle bin?</source>
        <translation>「%1」をゴミ箱に移動しますか？</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="781"/>
        <source>Failed to move file to trash</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="782"/>
        <source>Move to trash failed, it might caused by file permission issue, file system limitation, or platform limitation.</source>
        <translation>ゴミ箱への移動に失敗しました。ファイルのアクセス許可や、ファイルシステムの制限、プラットフォームの制限などを確認してください。</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="114"/>
        <source>Copy P&amp;ixmap</source>
        <translation>画像をコピー(&amp;I)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="115"/>
        <source>Copy &amp;File Path</source>
        <translation>ファイルパスをコピー(&amp;F)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="133"/>
        <source>Properties</source>
        <translation>プロパティ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="118"/>
        <location filename="../aboutdialog.cpp" line="41"/>
        <source>Stay on top</source>
        <translation>最前面に表示する</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="119"/>
        <location filename="../aboutdialog.cpp" line="44"/>
        <source>Protected mode</source>
        <translation>プロテクトモード</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="120"/>
        <location filename="../aboutdialog.cpp" line="47"/>
        <source>Keep transformation</source>
        <comment>The &apos;transformation&apos; means the flip/rotation status that currently applied to the image view</comment>
        <translation>表示状態を維持する</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="99"/>
        <source>Zoom in</source>
        <translation>拡大</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="100"/>
        <source>Zoom out</source>
        <translation>縮小</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="108"/>
        <source>Pause/Resume Animation</source>
        <translation>一時停止 / 再開のアニメーション</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="109"/>
        <source>Animation Go to Next Frame</source>
        <translation>次のフレームへ移動するアニメーション</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="111"/>
        <source>Flip &amp;Horizontally</source>
        <translation>画像を左右反転する(&amp;H)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="112"/>
        <source>Fit to view</source>
        <translation>表示に合わせる</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="113"/>
        <source>Fit to width</source>
        <translation>横幅に合わせる</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="116"/>
        <source>&amp;Paste</source>
        <translation>貼り付け(&amp;P)</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="101"/>
        <source>Toggle Checkerboard</source>
        <translation>背景を格子模様に切り替え</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="95"/>
        <source>&amp;Open...</source>
        <translation>開く(&amp;O)…</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="97"/>
        <source>Actual size</source>
        <translation>実際のサイズ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="98"/>
        <source>Toggle maximize</source>
        <translation>最大化を切り替える</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="102"/>
        <source>Rotate right</source>
        <translation>右に回転</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="103"/>
        <source>Rotate left</source>
        <translation>左に回転</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="105"/>
        <source>Previous image</source>
        <translation>前の画像</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="106"/>
        <source>Next image</source>
        <translation>次の画像</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="776"/>
        <location filename="../actionmanager.cpp" line="117"/>
        <source>Move to Trash</source>
        <translation>ゴミ箱へ移動する</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="121"/>
        <source>Configure...</source>
        <translation>設定...</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="122"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="125"/>
        <source>Show in File Explorer</source>
        <comment>File Explorer is the name of explorer.exe under Windows</comment>
        <translation>エクスプローラーで表示する</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="131"/>
        <source>Show in directory</source>
        <translation>ディレクトリに表示する</translation>
    </message>
    <message>
        <location filename="../actionmanager.cpp" line="134"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
</context>
<context>
    <name>MetadataDialog</name>
    <message>
        <location filename="../metadatadialog.cpp" line="84"/>
        <source>Image Metadata</source>
        <translation>画像メタデータ</translation>
    </message>
</context>
<context>
    <name>MetadataModel</name>
    <message>
        <location filename="../metadatamodel.cpp" line="43"/>
        <source>Origin</source>
        <comment>Section name.</comment>
        <translation>元の場所</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="44"/>
        <source>Image</source>
        <comment>Section name.</comment>
        <translation>イメージ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="48"/>
        <source>File</source>
        <comment>Section name.</comment>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="45"/>
        <source>Camera</source>
        <comment>Section name.</comment>
        <translation>カメラ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="35"/>
        <source>%1 File</source>
        <translation>%1 ファイル</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="42"/>
        <source>Description</source>
        <comment>Section name.</comment>
        <translation>説明</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="46"/>
        <source>Advanced photo</source>
        <comment>Section name.</comment>
        <translation>アドバンストフォト</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="47"/>
        <source>GPS</source>
        <comment>Section name.</comment>
        <translation>GPS</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="52"/>
        <source>Dimensions</source>
        <translation>解像度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="54"/>
        <source>Aspect ratio</source>
        <translation>アスペクト比</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="58"/>
        <source>Frame count</source>
        <translation>フレームカウント</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="62"/>
        <source>Name</source>
        <translation>画像名</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="64"/>
        <source>Item type</source>
        <translation>項目の種類</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="66"/>
        <source>Folder path</source>
        <translation>フォルダパス</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="68"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="70"/>
        <source>Date created</source>
        <translation>作成日時</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="72"/>
        <source>Date modified</source>
        <translation>更新日時</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="79"/>
        <source>Title</source>
        <translation>タイトル</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="81"/>
        <source>Subject</source>
        <translation>サブジェクト</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="83"/>
        <source>Rating</source>
        <translation>評価</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="85"/>
        <source>Tags</source>
        <translation>タグ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="87"/>
        <source>Comments</source>
        <translation>コメント</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="90"/>
        <source>Authors</source>
        <translation>作成者</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="92"/>
        <source>Date taken</source>
        <translation>撮影日時</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="98"/>
        <source>Program name</source>
        <translation>プログラム名</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="100"/>
        <source>Copyright</source>
        <translation>著作権</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="103"/>
        <source>Horizontal resolution</source>
        <translation>水平解像度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="105"/>
        <source>Vertical resolution</source>
        <translation>垂直解像度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="107"/>
        <source>Resolution unit</source>
        <translation>解像度の単位</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="109"/>
        <source>Colour representation</source>
        <translation>色空間</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="112"/>
        <source>Camera maker</source>
        <translation>カメラの製造元</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="114"/>
        <source>Camera model</source>
        <translation>カメラのモデル</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="116"/>
        <source>F-stop</source>
        <translation>絞り値</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="118"/>
        <source>Exposure time</source>
        <translation>露光時間</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="120"/>
        <source>ISO speed</source>
        <translation>ISO速度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="122"/>
        <source>Exposure bias</source>
        <translation>露光補正</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="124"/>
        <source>Focal length</source>
        <translation>焦点距離</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="126"/>
        <source>Max aperture</source>
        <translation>最大口径</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="128"/>
        <source>Metering mode</source>
        <translation>測光モード</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="130"/>
        <source>Subject distance</source>
        <translation>被写体距離</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="132"/>
        <source>Flash mode</source>
        <translation>フラッシュモード</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="134"/>
        <source>35mm focal length</source>
        <translation>35mm 焦点距離</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="137"/>
        <source>Lens model</source>
        <translation>レンズモデル</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="139"/>
        <source>Contrast</source>
        <translation>コントラスト</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="141"/>
        <source>Brightness</source>
        <translation>輝度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="143"/>
        <source>Exposure program</source>
        <translation>露光プログラム</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="145"/>
        <source>Saturation</source>
        <translation>彩度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="147"/>
        <source>Sharpness</source>
        <translation>シャープネス</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="149"/>
        <source>White balance</source>
        <translation>ホワイトバランス</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="151"/>
        <source>Digital zoom</source>
        <translation>デジタルズーム倍率</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="153"/>
        <source>EXIF version</source>
        <translation>EXIFバージョン</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="156"/>
        <source>Latitude reference</source>
        <translation>緯度基準</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="158"/>
        <source>Latitude</source>
        <translation>緯度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="160"/>
        <source>Longitude reference</source>
        <translation>経度基準</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="162"/>
        <source>Longitude</source>
        <translation>経度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="164"/>
        <source>Altitude reference</source>
        <translation>高度基準</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="166"/>
        <source>Altitude</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="176"/>
        <source>%1 x %2</source>
        <translation>%1 × %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="194"/>
        <source>%1 : %2</source>
        <translation>%1 : %2</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Property</source>
        <translation>プロパティ</translation>
    </message>
    <message>
        <location filename="../metadatamodel.cpp" line="319"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="31"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="51"/>
        <source>Shortcuts</source>
        <translation>ショートカット</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="61"/>
        <source>Editing shortcuts for action &quot;%1&quot;:</source>
        <translation>「%1」のショートカットを編集します:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="70"/>
        <source>Failed to set shortcuts</source>
        <translation>ショートカットの設定に失敗しました</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="71"/>
        <source>Please check if shortcuts are duplicated with existing shortcuts.</source>
        <translation>既存のショートカットと重複していないことを確認してください。</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="78"/>
        <source>Do nothing</source>
        <translation>何もしない</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="79"/>
        <source>Close the window</source>
        <translation>ウィンドウを終了する</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="80"/>
        <source>Toggle maximize</source>
        <translation>最大サイズに切り替える</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="81"/>
        <source>Toggle fullscreen</source>
        <translation>フルスクリーン表示に切り替える</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="85"/>
        <source>Zoom in and out</source>
        <translation>拡大・縮小</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="86"/>
        <source>View next or previous item</source>
        <translation>次の項目または前の項目を表示</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="90"/>
        <source>Auto size</source>
        <translation>オートサイズ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="91"/>
        <source>Maximized</source>
        <translation>最大化</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="92"/>
        <source>Windowed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="96"/>
        <source>Round (Integer scaling)</source>
        <comment>This option means round up for .5 and above</comment>
        <translation>四捨五入 (整数スケーリング)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="97"/>
        <source>Ceil (Integer scaling)</source>
        <comment>This option means always round up</comment>
        <translation>切り上げ (整数スケーリング)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="98"/>
        <source>Floor (Integer scaling)</source>
        <comment>This option means always round down</comment>
        <translation>切り捨て (整数スケーリング)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="99"/>
        <source>Follow system (Fractional scaling)</source>
        <comment>This option means don&apos;t round</comment>
        <translation>システム設定に従う (小数スケーリング)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="122"/>
        <source>Stay on top when start-up</source>
        <translation>起動時に最前面に表示する</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="123"/>
        <source>Use built-in close window animation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="124"/>
        <source>Use light-color checkerboard</source>
        <translation>明るい色の格子模様を使用する</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="125"/>
        <source>Loop the loaded gallery</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="126"/>
        <source>Double-click behavior</source>
        <translation>ダブルクリックの動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="127"/>
        <source>Mouse wheel behavior</source>
        <translation>マウスホイールの動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="128"/>
        <source>Default window size</source>
        <translation>既定のウィンドウサイズ</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="129"/>
        <source>HiDPI scale factor rounding policy</source>
        <translation>高DPIスケーリングの四捨五入方法</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../shortcutedit.cpp" line="109"/>
        <source>No shortcuts</source>
        <translation>ショートカットなし</translation>
    </message>
</context>
<context>
    <name>ShortcutEditor</name>
    <message>
        <location filename="../shortcutedit.cpp" line="75"/>
        <source>Shortcut #%1</source>
        <translation>ショートカット #%1</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Pineapple Pictures</source>
        <translation>Pineapple Pictures</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="45"/>
        <source>List supported image format suffixes, and quit program.</source>
        <translation>サポートされている画像形式の拡張子を一覧表示し、プログラムを終了します。</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="49"/>
        <source>File list.</source>
        <translation>ファイルリスト</translation>
    </message>
</context>
</TS>
